@@ -24,6 +24,7 @@ from google.cloud.bigquery_connection_v1.types.connection import (
     AwsAccessRole,
     AwsCrossAccountRole,
     AwsProperties,
+    AzureProperties,
     CloudResourceProperties,
     CloudSpannerProperties,
     CloudSqlCredential,
@@ -43,6 +44,7 @@ __all__ = (
     "AwsAccessRole",
     "AwsCrossAccountRole",
     "AwsProperties",
+    "AzureProperties",
     "CloudResourceProperties",
     "CloudSpannerProperties",
     "CloudSqlCredential",
