@@ -32,6 +32,7 @@ __protobuf__ = proto.module(
         "AwsProperties",
         "AwsCrossAccountRole",
         "AwsAccessRole",
+        "AzureProperties",
         "CloudResourceProperties",
     },
 )
@@ -211,6 +212,10 @@ class Connection(proto.Message):
         aws (google.cloud.bigquery_connection_v1.types.AwsProperties):
             Amazon Web Services (AWS) properties.
 
+            This field is a member of `oneof`_ ``properties``.
+        azure (google.cloud.bigquery_connection_v1.types.AzureProperties):
+            Azure properties.
+
             This field is a member of `oneof`_ ``properties``.
         cloud_spanner (google.cloud.bigquery_connection_v1.types.CloudSpannerProperties):
             Cloud Spanner properties.
@@ -255,6 +260,12 @@ class Connection(proto.Message):
         oneof="properties",
         message="AwsProperties",
     )
+    azure = proto.Field(
+        proto.MESSAGE,
+        number=11,
+        oneof="properties",
+        message="AzureProperties",
+    )
     cloud_spanner = proto.Field(
         proto.MESSAGE,
         number=21,
@@ -294,6 +305,14 @@ class CloudSqlProperties(proto.Message):
             Type of the Cloud SQL database.
         credential (google.cloud.bigquery_connection_v1.types.CloudSqlCredential):
             Input only. Cloud SQL credential.
+        service_account_id (str):
+            Output only. The account ID of the service
+            used for the purpose of this connection.
+            When the connection is used in the context of an
+            operation in BigQuery, this service account will
+            serve as identity being used for connecting to
+            the CloudSQL instance specified in this
+            connection.
     """
 
     class DatabaseType(proto.Enum):
@@ -320,6 +339,10 @@ class CloudSqlProperties(proto.Message):
         number=4,
         message="CloudSqlCredential",
     )
+    service_account_id = proto.Field(
+        proto.STRING,
+        number=5,
+    )
 
 
 class CloudSqlCredential(proto.Message):
@@ -378,7 +401,7 @@ class AwsProperties(proto.Message):
         cross_account_role (google.cloud.bigquery_connection_v1.types.AwsCrossAccountRole):
             Authentication using Google owned AWS IAM
             user's access key to assume into customer's AWS
-            IAM Role.
+            IAM Role. Deprecated, do not use.
 
             This field is a member of `oneof`_ ``authentication_method``.
         access_role (google.cloud.bigquery_connection_v1.types.AwsAccessRole):
@@ -460,6 +483,66 @@ class AwsAccessRole(proto.Message):
     )
 
 
+class AzureProperties(proto.Message):
+    r"""Container for connection properties specific to Azure.
+
+    Attributes:
+        application (str):
+            Output only. The name of the Azure Active
+            Directory Application.
+        client_id (str):
+            Output only. The client id of the Azure
+            Active Directory Application.
+        object_id (str):
+            Output only. The object id of the Azure
+            Active Directory Application.
+        customer_tenant_id (str):
+            The id of customer's directory that host the
+            data.
+        redirect_uri (str):
+            The URL user will be redirected to after
+            granting consent during connection setup.
+        federated_application_client_id (str):
+            The client id of the user's Azure Active
+            Directory Application used for a federated
+            connection.
+        identity (str):
+            Output only. A unique Google-owned and
+            Google-generated identity for the Connection.
+            This identity will be used to access the user's
+            Azure Active Directory Application.
+    """
+
+    application = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    client_id = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    object_id = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    customer_tenant_id = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    redirect_uri = proto.Field(
+        proto.STRING,
+        number=5,
+    )
+    federated_application_client_id = proto.Field(
+        proto.STRING,
+        number=6,
+    )
+    identity = proto.Field(
+        proto.STRING,
+        number=7,
+    )
+
+
 class CloudResourceProperties(proto.Message):
     r"""Container for connection properties for delegation of access
     to GCP resources.
